@@ -192,10 +192,21 @@ macro_rules! define_stats {
 pub struct StatDefinitionTagged {
     /// The statistic definition
     pub defn: &'static (dyn StatDefinition + Sync),
-    /// THe fixed tag values.  The keys *must* match keys in `defn`.
+    /// The fixed tag values.  The keys *must* match keys in `defn`.
     pub fixed_tags: &'static [(&'static str, &'static str)],
 }
 
+impl StatDefinitionTagged {
+    /// Check if the passed set of fixed tags corresponds to this statistic definition.
+    pub fn has_fixed_groups(&self, tags: &[(&str, &str)]) -> bool {
+        if self.fixed_tags.len() != tags.len() {
+            return false;
+        }
+
+        self.fixed_tags.iter().all(|self_tag| tags.contains(self_tag))
+    }
+}
+
 /// A trait indicating that this log can be used to trigger a statistics change.
 pub trait StatTrigger {
     /// The list of stats that this trigger applies to.
@@ -292,7 +303,7 @@ impl Buckets {
                 .iter()
                 .enumerate()
                 .filter(|(_, limit)| match limit {
-                    BucketLimit::Num(b) => (value <= *b as f64),
+                    BucketLimit::Num(b) => value <= *b as f64,
                     BucketLimit::Unbounded => true,
                 })
                 .map(|(i, _)| i)
@@ -761,11 +772,11 @@ impl StatTypeData {
     }
 
     /// Get all the tags for this stat as a vector of `(name, value)` tuples.
-    fn get_tag_pairs<'a, 'b, 'c>(
-        &'a self,
-        tag_values: &'b str,
-        defn: &'c dyn StatDefinition,
-    ) -> Option<Vec<(&'static str, &'b str)>> {
+    fn get_tag_pairs<'a>(
+        &self,
+        tag_values: &'a str,
+        defn: &dyn StatDefinition,
+    ) -> Option<Vec<(&'static str, &'a str)>> {
         if let StatTypeData::BucketCounter(ref bucket_counter_data) = self {
             Some(bucket_counter_data.get_tag_pairs(tag_values, defn))
         } else {
@@ -875,11 +886,11 @@ impl BucketCounterData {
     }
 
     /// Get all the tags for this stat as a vector of `(name, value)` tuples.
-    fn get_tag_pairs<'a, 'b, 'c>(
-        &'a self,
-        tag_values: &'b str,
-        defn: &'c dyn StatDefinition,
-    ) -> Vec<(&'static str, &'b str)> {
+    fn get_tag_pairs<'a>(
+        &self,
+        tag_values: &'a str,
+        defn: &dyn StatDefinition,
+    ) -> Vec<(&'static str, &'a str)> {
         let mut tag_names = defn.group_by();
         // Add the bucket label name as an additional tag name.
         tag_names.push(self.buckets.label_name);
@@ -987,7 +998,7 @@ struct Stat {
 
 impl Stat {
     // Get all the tags for this stat as a vector of `(name, value)` tuples.
-    fn get_tag_pairs<'a, 'b>(&'a self, tag_values: &'b str) -> Vec<(&'static str, &'b str)> {
+    fn get_tag_pairs<'a>(&self, tag_values: &'a str) -> Vec<(&'static str, &'a str)> {
         // if the stat type has its own `get_tag_pairs` method use that, otherwise
         // use the default.
         self.stat_type_data
